@@ -1820,11 +1820,7 @@ bool gApplication::disableInputEvents(bool disable)
 
 bool gApplication::eventsPending()
 {
-	/*if (areInputEventsEnabled() && _input_events && !g_queue_is_empty(_input_events))
-		return true;*/
-	
 	return gtk_events_pending();
-		
 }
 
 #ifdef GTK3
