@@ -1158,7 +1158,7 @@ void gTextArea::setFont(gFont *ft)
 
 void gTextArea::setBorder(bool b)
 {
-	gControl::setBorder(b);
+	setFrameBorder(b ? BORDER_SUNKEN : BORDER_NONE);
 	setFramePadding(hasBorder() ? gDesktop::scale() * 3 / 4 : 0);
 }
 
