@@ -28,6 +28,11 @@
 #include "gpicture.h"
 #include "gapplication.h"
 
+#if PANGO_VERSION_CHECK(1, 44, 0)
+#include <pango/pango-types.h>
+#include <fribidi.h>
+#endif
+
 // HTML character entities
 #include "kentities.h"
 
@@ -1711,6 +1716,47 @@ void gt_add_layout_from_font(PangoLayout *layout, gFont *font, int dpi)
 	set_layout_from_font(layout, font, true, dpi);
 }
 
+#if PANGO_VERSION_CHECK(1, 44, 0)
+// Replacement for pango_find_base_dir
+// Based on code from pango_unichar_direction and pango_find_base_dir
+// Taken from: https://github.com/lwindolf/liferea/pull/1018
+
+static PangoDirection find_base_dir(const gchar *text, gint length)
+{
+	FriBidiCharType fbd_ch_type;
+	PangoDirection dir = PANGO_DIRECTION_NEUTRAL;
+	const gchar *p;
+	gunichar ch;
+
+	G_STATIC_ASSERT (sizeof (FriBidiChar) == sizeof (gunichar));
+
+	g_return_val_if_fail (text != NULL || length == 0, PANGO_DIRECTION_NEUTRAL);
+
+	p = text;
+	while ((length < 0 || p < text + length) && *p)
+	{
+		ch = g_utf8_get_char (p);
+
+		fbd_ch_type = fribidi_get_bidi_type (ch);
+		if (!FRIBIDI_IS_STRONG (fbd_ch_type))
+			dir = PANGO_DIRECTION_NEUTRAL;
+		else
+			if (FRIBIDI_IS_RTL (fbd_ch_type))
+				dir = PANGO_DIRECTION_RTL;
+			else
+				dir = PANGO_DIRECTION_LTR;
+
+		if (dir != PANGO_DIRECTION_NEUTRAL)
+			break;
+
+		p = g_utf8_next_char (p);
+    }
+	return dir;
+}
+#else
+#define find_base_dir(_text, _len) pango_find_base_dir(_text, _len)
+#endif
+
 void gt_layout_alignment(PangoLayout *layout, const char *text, int len, float w, float h, float *tw, float *th, int align, float *offX, float *offY)
 {
 	int ptw, pth;
@@ -1723,7 +1769,7 @@ void gt_layout_alignment(PangoLayout *layout, const char *text, int len, float w
 
 	if (ALIGN_IS_NORMAL(align))
 	{
-		PangoDirection dir = pango_find_base_dir(text, len);
+		PangoDirection dir = find_base_dir(text, len);
 		
 		switch (align)
 		{
@@ -2068,8 +2114,8 @@ void gt_cairo_draw_pixbuf(cairo_t *cr, GdkPixbuf *pixbuf, float x, float y, floa
 #ifdef GTK3
 static GtkStyleContext *_style[NUM_STYLES] = { NULL };
 #else
-static int _style_loaded = 0;
-static GtkStyle *_style[NUM_STYLES];
+static uint _style_loaded = 0;
+static GtkStyle *_style[NUM_STYLES] = { NULL };
 #endif
 
 static int type_to_index(GType type)
@@ -2167,6 +2213,7 @@ static GtkStyle *get_style(const char *name, GType type)
 	GtkSettings *set = gtk_settings_get_default();
 	GtkStyle* st = gtk_rc_get_style_by_paths(set, NULL, name, type);
 	if (!st) st = gtk_widget_get_default_style();
+	g_object_ref(G_OBJECT(st));
 	return st;
 }
 
@@ -2175,6 +2222,7 @@ static GtkStyle *get_widget_style(const char *name)
 	GtkSettings *set = gtk_settings_get_default();
 	GtkStyle* st = gtk_rc_get_style_by_paths(set, name, NULL, G_TYPE_NONE);
 	if (!st) st = gtk_widget_get_default_style();
+	g_object_ref(G_OBJECT(st));
 	return st;
 }
 
@@ -2379,6 +2427,9 @@ void gt_on_theme_change()
 			g_object_unref(G_OBJECT(_style[i]));
 		_style[i] = NULL;
 	}
+#ifndef GTK3
+	_style_loaded = 0;
+#endif
 }
 
 #if GTK_CHECK_VERSION(3, 22, 0)
