@@ -598,9 +598,15 @@ static void hook_wait(int duration)
 	else if (duration == -1)
 	{
 		bool d = gApplication::disableInputEvents(true);
-		MAIN_do_iteration(true); // To process deferred routines
-		while (gApplication::eventsPending())
-			MAIN_do_iteration(false);
+		int i;
+		
+		for (i = 0; i < 256; i++)
+		{
+			if (!gApplication::eventsPending())
+				break;
+			MAIN_do_iteration(true);
+		}
+
 		gApplication::disableInputEvents(d);
 	}
 	else if (duration == -2)
@@ -678,13 +684,8 @@ void MAIN_do_iteration(bool do_not_block)
 
 	while (!gApplication::processInputEvent());
 	
-	if (do_not_block)
-	{
-		if (gApplication::eventsPending())
-			gtk_main_iteration();
-	}
-	else
-		gtk_main_iteration_do(true);
+	if (!do_not_block || gApplication::eventsPending())
+		gtk_main_iteration();
 
 	gApplication::_loopLevel--;
 
