@@ -121,7 +121,7 @@ static bool _internal_paint = false;
 
 static gFont *get_default_font(GB_PAINT *d)
 {
-	if (GB.Is(d->device, CLASS_DrawingArea) || GB.Is(d->device, CLASS_UserControl))
+	if (GB.Is(d->device, CLASS_DrawingArea) || GB.Is(d->device, CLASS_UserControl) || GB.Is(d->device, CLASS_UserContainer))
 	{
 		gControl *wid = (gControl *)((CWIDGET *)d->device)->widget;
 		return wid->font()->copy();
@@ -256,7 +256,7 @@ static int Begin(GB_PAINT *d)
 	void *device = d->device;
 	cairo_surface_t *target = NULL;
 	double w, h;
-	int rx = 96, ry = 96;
+	int rx = gDesktop::resolution(), ry = rx;
 
 	EXTRA(d)->print_context = NULL;
 	EXTRA(d)->dx = EXTRA(d)->dy = 0;
@@ -354,9 +354,6 @@ static int Begin(GB_PAINT *d)
 			dr = gtk_widget_get_window(wid->widget);
 		}
 
-		rx = gDesktop::resolution(); //device->physicalDpiX();
-		ry = gDesktop::resolution(); //device->physicalDpiY();
-
 		EXTRA(d)->context = gdk_cairo_create(dr);
 #endif
 
@@ -365,9 +362,9 @@ static int Begin(GB_PAINT *d)
 
 		cairo_translate(CONTEXT(d), dx, dy);
 	}
-	else if (GB.Is(device, CLASS_UserControl))
+	else if (GB.Is(device, CLASS_UserControl) || GB.Is(device, CLASS_UserContainer))
 	{
-		gContainer *wid = (gDrawingArea *)((CWIDGET *)device)->widget;
+		gContainer *wid = (gContainer *)((CWIDGET *)device)->widget;
 		double dx = 0, dy = 0;
 
 		w = wid->width();
@@ -380,7 +377,7 @@ static int Begin(GB_PAINT *d)
 		}
 
 #ifdef GTK3
-		EXTRA(d)->context = ((CUSERCONTROL *)device)->context;
+		EXTRA(d)->context = ((CUSERCONTROL *)device)->func.context;
 		cairo_reference(CONTEXT(d));
 #else
 		GdkDrawable *dr;
@@ -393,9 +390,6 @@ static int Begin(GB_PAINT *d)
 		EXTRA(d)->context = gdk_cairo_create(dr);
 #endif
 
-		rx = gDesktop::resolution();
-		ry = gDesktop::resolution();
-
 		EXTRA(d)->dx = dx;
 		EXTRA(d)->dy = dy;
 
@@ -972,23 +966,24 @@ static void Arc(GB_PAINT *d, float xc, float yc, float radius, float angle, floa
 
 static void Ellipse(GB_PAINT *d, float x, float y, float width, float height, float angle, float length, bool pie)
 {
-	x += DX(d);
-	y += DY(d);
-
-	cairo_new_sub_path(CONTEXT(d));
+	x += DX(d) + width / 2;
+	y += DY(d) + height / 2;
 
 	cairo_save(CONTEXT(d));
 
-	cairo_translate(CONTEXT(d), x + width / 2, y + height / 2);
+	cairo_translate(CONTEXT(d), x, y);
 	cairo_scale(CONTEXT(d), width / 2, height / 2);
+	cairo_translate(CONTEXT(d), -x, -y);
 
 	if (pie)
-		cairo_move_to(CONTEXT(d), 0, 0);
+		cairo_move_to(CONTEXT(d), x, y);
+	else
+		cairo_new_sub_path(CONTEXT(d));
 
 	if (length < 0.0)
-		cairo_arc_negative(CONTEXT(d), 0, 0, 1, angle, angle + length);
+		cairo_arc_negative(CONTEXT(d), x, y, 1, angle, angle + length);
 	else
-		cairo_arc(CONTEXT(d), 0, 0, 1, angle, angle + length);
+		cairo_arc(CONTEXT(d), x, y, 1, angle, angle + length);
 
 	if (pie)
 		cairo_close_path(CONTEXT(d));
@@ -1039,7 +1034,10 @@ static PangoLayout *create_pango_layout(GB_PAINT *d)
 	GB_PAINT_EXTRA *dx = EXTRA(d);
 
 	if (!dx->layout)
+	{
 		dx->layout = pango_cairo_create_layout(dx->context);
+		pango_cairo_context_set_resolution(pango_layout_get_context(dx->layout), d->resolutionX);
+	}
 
 	return dx->layout;
 }
