@@ -1035,9 +1035,6 @@ void gControl::updateCursor(GdkCursor *cursor)
 		return;
 
 	gdk_window_set_cursor(win, cursor);
-
-	/*if (!cursor && parent())
-		parent()->updateCursor(parent()->getGdkCursor());*/
 }
 
 GdkCursor *gControl::getGdkCursor()
@@ -1052,7 +1049,11 @@ GdkCursor *gControl::getGdkCursor()
 	if (m == CURSOR_CUSTOM)
 	{
 		if (curs && curs->cur)
-			return curs->cur;
+		#ifdef GTK3
+			return (GdkCursor *)g_object_ref(curs->cur);
+		#else
+			return gdk_cursor_ref(curs->cur);
+		#endif
 	}
 
 	if (m != CURSOR_DEFAULT)
@@ -2133,13 +2134,6 @@ bool gControl::hasBorder() const
 	return getFrameBorder() != BORDER_NONE;
 }
 
-void gControl::setBorder(bool vl)
-{
-	setFrameBorder(vl ? BORDER_SUNKEN : BORDER_NONE);
-	_has_border = vl;
-}
-
-
 void gControl::setFramePadding(int padding)
 {
 	if (padding < 0)
