@@ -656,7 +656,17 @@ END_PROPERTY
 
 BEGIN_PROPERTY(WebViewHistoryItem_Title)
 
+#if WEBKIT_CHECK_VERSION(2, 44, 0)
+	static bool _warning = FALSE;
+	if (!_warning)
+	{
+		_warning = TRUE;
+		fprintf(stderr, "gb.gtk3.webview: warning: WebKitGTK history does not store page titles anymore.\n");
+	}
+	GB.ReturnVoidString();
+#else
 	GB.ReturnNewZeroString(webkit_back_forward_list_item_get_title(THIS->item));
+#endif
 
 END_PROPERTY
 
@@ -674,8 +684,13 @@ END_METHOD
 
 BEGIN_METHOD_VOID(WebViewHistory_Clear)
 
-	fprintf(stderr, "gb.gtk3.webview: warning: WebKitGTK does not know how to clear its history at the moment.\n");
-
+	static bool _warning = FALSE;
+	if (!_warning)
+	{
+		_warning = TRUE;
+		fprintf(stderr, "gb.gtk3.webview: warning: WebKitGTK does not know how to clear its history.\n");
+	}
+	
 END_METHOD
 
 BEGIN_METHOD(WebViewHistory_get, GB_INTEGER index)
