@@ -365,7 +365,6 @@ static void http_send(void *_object, int type, char *sContent, char *sData, int
 		}
 		else
 			THIS_HTTP->data = NULL;
-		
 	}
 	
 	THIS_HTTP->len_sent = 0;
@@ -390,12 +389,12 @@ static void http_send(void *_object, int type, char *sContent, char *sData, int
 	
 	if (type == SEND_PUT)
 	{
-		curl_easy_setopt(THIS_CURL, CURLOPT_INFILESIZE_LARGE, (curl_off_t)lendata);
+		curl_easy_setopt(THIS_CURL, CURLOPT_INFILESIZE_LARGE, (curl_off_t)THIS_HTTP->len_data);
 		curl_easy_setopt(THIS_CURL, CURLOPT_UPLOAD, 1);
 	}
 	else // SEND_POST
 	{
-		curl_easy_setopt(THIS_CURL, CURLOPT_POSTFIELDSIZE, lendata);
+		curl_easy_setopt(THIS_CURL, CURLOPT_POSTFIELDSIZE, THIS_HTTP->len_data);
 		curl_easy_setopt(THIS_CURL, CURLOPT_POSTFIELDS, NULL);
 	}
 
