@@ -3196,12 +3196,9 @@ bool CWidget::eventFilter(QObject *widget, QEvent *event)
 					while (abs(EXT(control)->wheel_x) >= 120)
 					{
 						cancel = GB.Raise(control, EVENT_MouseWheel, 0);
-						if (cancel)
-						{
-							EXT(control)->wheel_x = 0;
-							break;
-						}
 						EXT(control)->wheel_x -= d;
+						if (cancel)
+							break;
 					}
 				}
 
@@ -3214,12 +3211,9 @@ bool CWidget::eventFilter(QObject *widget, QEvent *event)
 					while (abs(EXT(control)->wheel_y) >= 120)
 					{
 						cancel = GB.Raise(control, EVENT_MouseWheel, 0);
-						if (cancel)
-						{
-							EXT(control)->wheel_y = 0;
-							break;
-						}
 						EXT(control)->wheel_y -= d;
+						if (cancel)
+							break;
 					}
 				}
 
