@@ -80,6 +80,21 @@ int compare_short(const short *a, const short *b)
 }
 
 
+int compare_boolean(const uchar *a, const uchar *b)
+{
+	int comp;
+
+	if (!*a && *b)
+		comp = -1;
+	else if (*a && !*b)
+		comp = 1;
+	else
+		return 0;
+
+	return _descent ? (-comp) : comp;
+}
+
+
 int compare_byte(const uchar *a, const uchar *b)
 {
 	int comp;
@@ -628,15 +643,17 @@ COMPARE_FUNC COMPARE_get_func(TYPE type, int mode)
 
 	switch(type)
 	{
-		case T_INTEGER:
-			return (COMPARE_FUNC)compare_integer;
+		case T_BOOLEAN:
+			return (COMPARE_FUNC)compare_boolean;
 
+		case T_BYTE:
+			return (COMPARE_FUNC)compare_byte;
+			
 		case T_SHORT:
 			return (COMPARE_FUNC)compare_short;
 
-		case T_BYTE:
-		case T_BOOLEAN:
-			return (COMPARE_FUNC)compare_byte;
+		case T_INTEGER:
+			return (COMPARE_FUNC)compare_integer;
 
 		case T_LONG:
 			return (COMPARE_FUNC)compare_long;
