@@ -174,7 +174,7 @@ static inline STREAM *_get_stream(VALUE *value, bool can_default)
 ({ \
 	STREAM *_stream = _get_stream(_value, _can_default); \
 	\
-	if (!_stream || STREAM_is_closed(_stream)) \
+	if (_stream && STREAM_is_closed(_stream)) \
 		THROW(E_CLOSED); \
 	\
 	_stream; \
@@ -184,7 +184,7 @@ static inline STREAM *_get_stream(VALUE *value, bool can_default)
 ({ \
 	STREAM *_stream = _get_stream(_value, _can_default); \
 	\
-	if (!_stream || STREAM_is_closed_for_writing(_stream)) \
+	if (_stream && STREAM_is_closed_for_writing(_stream)) \
 		THROW(E_CLOSED); \
 	\
 	_stream; \
