@@ -1958,12 +1958,12 @@ static bool push_subr_cat(ushort code)
 	else if (PCODE_is(code_pop, C_POP_STATIC))
 	{
 		void *addr = &JIT_class->stat[JIT_class->load->stat[index].pos];
-		JIT_print("  JIT.add_string_global((char *)%p, as);\n", addr);
+		JIT_print("  JIT.add_string_global((char **)%p, as);\n", addr);
 	}
 	else if (PCODE_is(code_pop, C_POP_DYNAMIC))
 	{
 		int pos = JIT_class->load->dyn[index].pos;
-		JIT_print("  JIT.add_string_global(&OP[%d], as);\n", pos);
+		JIT_print("  JIT.add_string_global((char **)&OP[%d], as);\n", pos);
 	}
 	
 	return TRUE;
